One Shot Blog: Zed A. Shaw

# One. Shot. Blog.

- latest
- about

- Software Copyright (C) 2009 Zed Shaw. Posts Copyright by their owners, sue them.

## OneShotBlog Help

OneShotBlog(TM) takes your blog post from your email. That's pretty much it. The email address you use @oneshotblog.com can be any tag you want, which will be used as the file name for your page. Don't worry though, we won't let you pick some stupid name like ../../../../etc/passwd. When you send your email, you get a confirmation, then your page is posted. That's it. It can be anything that starts with a character or number, and has characters, numbers, or periods in it.

A tag like i.want.my.blog@oneshotblog.com works, a tag like ohreally?@oneshotblog.com does not.

It's not a blog in the traditional sense though, since your post is just put onto the main index. Instead it's for a single shot page you want to share, kind of like a paste-bin service if you will. That'll probably change in the future, but for now, you send a post, it gets created, and it's put in the index.

Since most people's first post is something lame like "testing" we don't index that one. You second one after you are confirmed is the real one. That first one is to just make sure your gear works.

You can delete your posts too, and the email you get tells you how. However, if you delete a post, it's still shown in the index for now. Sorry, this is alpha software my friends.

This server will be temporary, and will be taken down periodically. You'll be notified when it's made official.

Finally, this whole thing is written using a tiny amount of Lamson code. Check the project out if you want to do cool things with email.